@@ -3,7 +3,7 @@ package JSON::Tiny;
 # Minimalistic JSON. Adapted from Mojo::JSON.
 # (c)2012-2014 David Oswald
 # License: Artistic 2.0 license.
-# http://www.perlfoundation.org/artistic_license_2_0.
+# http://www.perlfoundation.org/artistic_license_2_0
 
 use strict;
 use warnings;
@@ -13,7 +13,7 @@ use Exporter 'import';
 use Scalar::Util 'blessed';
 use Encode ();
 
-our $VERSION = '0.49';
+our $VERSION = '0.50';
 our @EXPORT_OK = qw(decode_json encode_json j);
 
 # Constructor and error inlined from Mojo::Base
@@ -54,8 +54,6 @@ for(0x00 .. 0x1f) {
     if ! defined $REVERSE{$packed};
 }
 
-my $WHITESPACE_RE = qr/[\x20\x09\x0a\x0d]*/;
-
 sub decode {
   my $self = shift->error(undef);
   my $value;
@@ -99,23 +97,23 @@ sub _decode {
   my $value = _decode_value();
   
   # Leftover data
-  _exception('Unexpected data') unless m/\G$WHITESPACE_RE\z/gc;
+  _exception('Unexpected data') unless m/\G[\x20\x09\x0a\x0d]*\z/gc;
 
   return $value;
 }
 
 sub _decode_array {
   my @array;
-  until (m/\G$WHITESPACE_RE\]/gc) {
+  until (m/\G[\x20\x09\x0a\x0d]*\]/gc) {
 
     # Value
     push @array, _decode_value();
 
     # Separator
-    redo if m/\G$WHITESPACE_RE,/gc;
+    redo if m/\G[\x20\x09\x0a\x0d]*,/gc;
 
     # End
-    last if m/\G$WHITESPACE_RE\]/gc;
+    last if m/\G[\x20\x09\x0a\x0d]*\]/gc;
 
     # Invalid character
     _exception('Expected comma or right square bracket while parsing array');
@@ -126,27 +124,27 @@ sub _decode_array {
 
 sub _decode_object {
   my %hash;
-  until (m/\G$WHITESPACE_RE\}/gc) {
+  until (m/\G[\x20\x09\x0a\x0d]*\}/gc) {
 
     # Quote
-    m/\G$WHITESPACE_RE"/gc
+    m/\G[\x20\x09\x0a\x0d]*"/gc
       or _exception('Expected string while parsing object');
 
     # Key
     my $key = _decode_string();
 
     # Colon
-    m/\G$WHITESPACE_RE:/gc
+    m/\G[\x20\x09\x0a\x0d]*:/gc
       or _exception('Expected colon while parsing object');
 
     # Value
     $hash{$key} = _decode_value();
 
     # Separator
-    redo if m/\G$WHITESPACE_RE,/gc;
+    redo if m/\G[\x20\x09\x0a\x0d]*,/gc;
 
     # End
-    last if m/\G$WHITESPACE_RE\}/gc;
+    last if m/\G[\x20\x09\x0a\x0d]*\}/gc;
 
     # Invalid character
     _exception('Expected comma or right curly bracket while parsing object');
@@ -213,7 +211,7 @@ sub _decode_string {
 sub _decode_value {
 
   # Leading whitespace
-  m/\G$WHITESPACE_RE/gc;
+  m/\G[\x20\x09\x0a\x0d]*/gc;
 
   # String
   return _decode_string() if m/\G"/gc;
@@ -297,7 +295,7 @@ sub _encode_value {
 sub _exception {
 
   # Leading whitespace
-  m/\G$WHITESPACE_RE/gc;
+  m/\G[\x20\x09\x0a\x0d]*/gc;
 
   # Context
   my $context = 'Malformed JSON: ' . shift;
